% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.

clear all;

% Model generated from The Biochemical Simulation Environment (BISEN).

% Pyruvate Dehydrogenase reaction (EC 1.2.4.1/EC 2.3.1.12/EC 1.8.1.4).

% Note: Be wary of pH ([H+]) generating imaginary numbers (negative [H+]).

%% Building model:
%ModelInfo = BuildDXDT('PDH.bsl','PDH.m');

%% Setting up and running Example 1
% (1.) Setting parameter values (no buffering)
B_X   = 0;      % Additional proton buffering capacity
K_BX = 1e-7;    % Dissociation constant of additional proton buffer
par(1) = 0.001;     % Vf_FUM
T = 25;             % Temperature

% (2.) Setting initial values
xo(1) = 1.5e-3;     % Pyruvate (M)
xo(2) = 1e-4;       % COAS (M)
xo(3) = 1e-3;       % NAD (M)
xo(4) = 0;          % CO2 (M)
xo(5) = 2e-3;       % AcetylcoA (M)
xo(6) = 5e-4;       % NADH (M)
xo(7) = 1e-7;       % [H] (M)
xo(8) = 1e-3;       % [Mg] (M)
xo(9) = 150e-3;     % [K] (M)

% (3.) Running for 15-second time course
[t,x] = ode15s(@PDH,[0 15],xo,[],T,B_X,K_BX,par);
% (4.) Plotting results
figure(1); p = plot(t,x(:,1)*1e3,'k-',t,x(:,2)*1e3,'k:',t,x(:,5)*1e3,'ko');
set(p,'linewidth',1.5);
text(1,1.2,'Pyruvate','Fontsize',14);
text(1,0.125,'COAS','Fontsize',14);
text(1,1.95,'AcetylcoA','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(2); p = plot(t,x(:,3)*1e3,'k-',t,x(:,6)*1e3,'k:');
set(p,'linewidth',1.5);
text(5,.95,'NAD','Fontsize',14);
text(5,.55,'NADH','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(3); p = plot(t,-log10(x(:,7)),'k-','LineWidth',1.5);
ylabel('pH','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(4); p = plot(t,x(:,4)*1e3,'k-');
set(p,'linewidth',1.5);
text(2,.05,'CO2','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);


Table = array2table([t,x],'variableNames',{'Time','BISEN_Pyr','BISEN_COAS','BISEN_NAD','CO2', 'AcetylCoA', 'NADH','BISEN_H','BISEN_Mg','BISEN_K'});
S1 = 'PDHBisenOutput';
S2 = '.csv';
filename1 = strcat(S1);  % Append runtime to filename
filename = strcat(filename1,S2);
%filename = 'PDHBisenOutput.csv';
writetable(Table,filename);
%%
